Module parsing

Module parsing 

Modules

elements
indexation
lang_token
operation_priority
type_token
types
vector_priority

Structs

ParseResult
Result of parsing containing the AST and any syntax errors collected

Functions

base_parse
module
parse
Parse source code and return a ParseResult containing the AST and any syntax errors
parse2
parse_from_string
Parse source code from a string with a filename for error reporting
parse_from_string_with_errors
Parse source code from a string with a filename, returning full ParseResult
parse_legacy
Parse source code and return just the Lang AST (legacy behavior)
push_parse_error
signature
simple_exp