Modules
Structs
- Parse
Result - Result of parsing containing the AST and any syntax errors collected
Functions
- base_
parse - module
- parse
- Parse source code and return a ParseResult containing the AST and any syntax errors
- parse2
- parse_
from_ string - Parse source code from a string with a filename for error reporting
- parse_
from_ string_ with_ errors - Parse source code from a string with a filename, returning full ParseResult
- parse_
legacy - Parse source code and return just the Lang AST (legacy behavior)
- push_
parse_ error - signature
- simple_
exp