Module transpiling

Module transpiling 

Modules

translatable

Traits

ToSome

Functions

clear_generated_files
Clear all generated files
escape_r_string
Render a string value as an R double-quoted literal (R’s canonical string form). The value is assumed to be already decoded (see parsing::elements::decode_escapes), so this is the single place that knows how to escape for the R target: backslashes and double quotes must be escaped, control characters are emitted as escape sequences.
get_generated_files
Get all generated files
register_generated_file
Register a generated file (used for WASM mode to capture file outputs)
reset_import_from_stack
reset_include_stack
Reset the include stack to a single empty bottom frame (call before a build).
take_main_import_froms
take_main_includes
Drain the bottom (main) frame — the top-level includes for main.R.